
#include "qmaemo5homescreenadaptor.h"
#include "mainwidget.h"

#include <QtGui>
#include <QtDBus>

int main(int argc, char *argv[])
{
    // enforce native graphics system for now due to a bug in transparency handling
    // you can remove this line if you only target PR 1.2
    QApplication::setGraphicsSystem("native");

    QApplication app(argc, argv);
    app.setApplicationName("Profile Changer Widget");


    MainWidget w;
/*    
    if (!QDBusConnection::sessionBus().isConnected()) {
        qWarning("Cannot connect to the D-Bus session bus.");
        exit(1);
    }
 
    if (!QDBusConnection::sessionBus().registerService("org.indt.sample")) {
        qWarning("%s", qPrintable(QDBusConnection::sessionBus().lastError().
            message()));
        exit(2);
    }
 
    if (!QDBusConnection::sessionBus().registerObject("/org/indt/sample", &w,
        QDBusConnection::ExportScriptableSlots)) {
        qWarning("%s", qPrintable(QDBusConnection::sessionBus().lastError().
            message()));
        exit(3);
    }
*/
    QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&w);
    adaptor->setSettingsAvailable(false);
 //   QObject::connect(adaptor, SIGNAL(settingsRequested()), &w, SLOT(showSettingsDialog()));
    w.show();

    return app.exec();
}

